# Flexitricity Data Tool Kit 🛠️

Handy tools for data access within Flexitricity.

Note that for easier distribution this project is open source, although it's unlikely that functions within here would be of use as packaged, outside of the company context.
